@@ -1,17 +1,17 @@
 from .enum import DeviceType
-from ..object.Gateway import Gateway
-from ..object.Agent import Agent
+from ..objects.synchronous import edge, drive
+from ..common import parse_base_object_ref
 
 
 def remote_command(Portal, device):
-    port = Portal.port()
-    https = Portal.https()
+    tenant = parse_base_object_ref(device.portal).name
+    base = f'{Portal.ctera.baseurl}/devicecmdnew/{tenant}/{device.name}'
 
     ManagedDevice = None
     if device.deviceType in DeviceType.Gateways:
-        ManagedDevice = Gateway(host=device.name, port=port, https=https, Portal=Portal)
+        ManagedDevice = edge.Edge(Portal=Portal, base=base)
     elif device.deviceType in DeviceType.Agents:
-        ManagedDevice = Agent(host=device.name, port=port, https=https, Portal=Portal)
+        ManagedDevice = drive.Drive(Portal=Portal, base=base)
     elif device.deviceType == "Mobile":
         return device
     else:
