@@ -2,23 +2,26 @@ import re
 import logging
 
 from ..lib.task_manager_base import TaskBase
-from ..exception import InputError
+from ..exceptions import InputError
 from .base_command import BaseCommand
 
 
+logger = logging.getLogger('cterasdk.core')
+
+
 class Task(TaskBase):
 
     def _get_task_id(self, ref):
         match = re.search('servers/[^/]*/bgTasks/[1-9][0-9]*$', ref)
         if not match:
-            logging.getLogger().error('Invalid task id. %s', {'ref': ref})
+            logger.error('Invalid task id. %s', {'ref': ref})
             raise InputError('Invalid task id', ref, ['servers/server/bgTasks/107781'])
         return match.group(0)
 
     def get_task_status(self):
         if self.CTERAHost.session().in_tenant_context():
-            return self.CTERAHost.execute('', 'getTaskStatus', self.path)
-        return self.CTERAHost.get('/' + self.path)
+            return self.CTERAHost.api.execute('', 'getTaskStatus', self.path)
+        return self.CTERAHost.api.get('/' + self.path)
 
 
 class Tasks(BaseCommand):
@@ -30,8 +33,8 @@ class Tasks(BaseCommand):
 
         :param str ref: Task reference
         """
-        task = Task(self._portal, ref)
-        return task.status()
+        task = Task(self._core, ref)
+        return task.get_task_status()
 
     def wait(self, ref, retries=100, seconds=1):
         """
@@ -41,5 +44,5 @@ class Tasks(BaseCommand):
         :param int,optional retries: Number of retries when sampling the task status, defaults to 100
         :param int,optional seconds: Number of seconds to wait between retries, defaults to 1
         """
-        task = Task(self._portal, ref, retries, seconds)
+        task = Task(self._core, ref, retries, seconds)
         return task.wait()
