@@ -1,9 +1,10 @@
 from abc import ABC
 from collections import namedtuple
-from ..common import DateTimeUtils, StringCriteriaBuilder, ListCriteriaBuilder, Object
-from ..lib import FileSystem
+from ..common import DateTimeUtils, StringCriteriaBuilder, PredefinedListCriteriaBuilder, CustomListCriteriaBuilder, Object
+from ..lib.storage import commonfs
 
-from .enum import PortalAccountType, CollaboratorType, FileAccessMode, PlanCriteria, TemplateCriteria, BucketType, LocationType, Platform
+from .enum import PortalAccountType, CollaboratorType, FileAccessMode, PlanCriteria, TemplateCriteria, \
+                  BucketType, LocationType, Platform, RetentionMode, Duration, ExtendedAttributes
 
 
 CloudFSFolderFindingHelper = namedtuple('CloudFSFolderFindingHelper', ('name', 'owner'))
@@ -210,11 +211,11 @@ class PlanCriteriaBuilder:
 
     @staticmethod
     def user_groups():
-        return ListCriteriaBuilder(PlanCriteriaBuilder.Type, PlanCriteria.Groups)
+        return CustomListCriteriaBuilder(PlanCriteriaBuilder.Type, PlanCriteria.Groups)
 
     @staticmethod
     def role():
-        return ListCriteriaBuilder(PlanCriteriaBuilder.Type, PlanCriteria.Role)
+        return PredefinedListCriteriaBuilder(PlanCriteriaBuilder.Type, PlanCriteria.Role)
 
     @staticmethod
     def first_name():
@@ -243,7 +244,7 @@ class TemplateCriteriaBuilder:
 
     @staticmethod
     def type():
-        return ListCriteriaBuilder(TemplateCriteriaBuilder.Type, TemplateCriteria.Type)
+        return PredefinedListCriteriaBuilder(TemplateCriteriaBuilder.Type, TemplateCriteria.Type)
 
     @staticmethod
     def os():
@@ -289,13 +290,18 @@ class Bucket:
 
 class HTTPBucket(Bucket):
 
-    def __init__(self, bucket, driver, access_key, secret_key, endpoint, https, direct=False):
+    def __init__(self, bucket, driver, access_key, secret_key, endpoint, https, direct=False, verify_ssl=True):
         super().__init__(bucket, driver)
         self.access_key = access_key
         self.secret_key = secret_key
         self.endpoint = endpoint
         self.https = https
         self.direct = direct
+        self.verify_ssl = verify_ssl
+
+    @property
+    def trust_all_certificates(self):
+        return not self.verify_ssl
 
 
 class AzureBlob(HTTPBucket):
@@ -317,8 +323,8 @@ class AzureBlob(HTTPBucket):
 class S3Compatible(HTTPBucket):
 
     def __init__(self, bucket, driver, access_key, secret_key,
-                 endpoint, https, direct):
-        super().__init__(bucket, driver, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https, direct, verify_ssl):
+        super().__init__(bucket, driver, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
     def to_server_object(self):
         param = super().to_server_object()
@@ -328,56 +334,57 @@ class S3Compatible(HTTPBucket):
         param.awsSecretKey = self.secret_key
         param.useHttps = self.https
         param.directUpload = self.direct
+        param.trustAllCertificates = self.trust_all_certificates
         return param
 
 
 class Scality(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False):
-        super().__init__(bucket, BucketType.Scality, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.Scality, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
 
 class ICOS(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False):
-        super().__init__(bucket, BucketType.ICOS, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.ICOS, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
 
 class Nutanix(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False):
-        super().__init__(bucket, BucketType.Nutanix, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.Nutanix, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
 
 class Wasabi(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False):
-        super().__init__(bucket, BucketType.Wasabi, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.Wasabi, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
 
 class Google(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False):
-        super().__init__(bucket, BucketType.Google, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.Google, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
 
 class GenericS3(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False):
-        super().__init__(bucket, BucketType.GenericS3, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.GenericS3, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
 
 class NetAppStorageGRID(S3Compatible):
 
     def __init__(self, bucket, access_key, secret_key,
-                 endpoint, https=False, direct=False, tags=False):
-        super().__init__(bucket, BucketType.NetAppStorageGRID, access_key, secret_key, endpoint, https, direct)
+                 endpoint, https=False, direct=False, tags=False, verify_ssl=True):
+        super().__init__(bucket, BucketType.NetAppStorageGRID, access_key, secret_key, endpoint, https, direct, verify_ssl)
         self.tagBlocks = tags
 
     def to_server_object(self):
@@ -388,8 +395,8 @@ class NetAppStorageGRID(S3Compatible):
 
 class AmazonS3(HTTPBucket):
 
-    def __init__(self, bucket, access_key, secret_key, endpoint='s3.amazonaws.com', https=True, direct=True):
-        super().__init__(bucket, BucketType.AWS, access_key, secret_key, endpoint, https, direct)
+    def __init__(self, bucket, access_key=None, secret_key=None, endpoint='s3.amazonaws.com', https=True, direct=True, verify_ssl=True):
+        super().__init__(bucket, BucketType.AWS, access_key, secret_key, endpoint, https, direct, verify_ssl)
 
     def to_server_object(self):
         param = super().to_server_object()
@@ -399,6 +406,7 @@ class AmazonS3(HTTPBucket):
         param.awsSecretKey = self.secret_key
         param.httpsOnly = self.https
         param.directUpload = self.direct
+        param.trustAllCertificates = self.trust_all_certificates
         return param
 
 
@@ -420,6 +428,7 @@ class DomainControllers:
 class AccessControlRule(Object):
 
     def __init__(self, group, role):
+        super().__init__()
         self._classname = 'AccessControlRule'
         self.group = group
         self.role = role
@@ -487,7 +496,7 @@ class TemplateScript:
 
     @staticmethod
     def _get_contents(shell_script):
-        if FileSystem.instance().exists(shell_script):
+        if commonfs.exists(shell_script):
             with open(shell_script, 'r', encoding='utf-8') as f:
                 data = f.read()
             return data
@@ -602,6 +611,7 @@ class AlertBuilder:
 class Task(Object):
 
     def __init__(self, task_id, name):
+        super().__init__()
         self.id = task_id
         self.name = name
 
@@ -644,3 +654,176 @@ class BackgroundTask(Task):
             server_object.progstring,
             ref
         )
+
+
+class ComplianceSettingsBuilder:
+
+    def __init__(self, enabled, mode, retain_for):
+        self.settings = Object()
+        self.settings._classname = 'WormSettings'  # pylint: disable=protected-access
+        self.settings.worm = enabled
+        self.settings.retentionMode = mode
+        self.settings.retentionPeriod = retain_for
+        self.settings.gracePeriod = None
+
+    @staticmethod
+    def default():
+        return ComplianceSettingsBuilder(False, RetentionMode.Delete, None)
+
+    @staticmethod
+    def none(amount, duration):
+        return ComplianceSettingsBuilder(True, RetentionMode.Delete, ComplianceSettingsBuilder._get_retention_period(amount, duration))
+
+    @staticmethod
+    def enterprise(amount, duration):
+        return ComplianceSettingsBuilder(True, RetentionMode.Enterprise, ComplianceSettingsBuilder._get_retention_period(amount, duration))
+
+    @staticmethod
+    def compliance(amount, duration):
+        return ComplianceSettingsBuilder(True, RetentionMode.Compliance, ComplianceSettingsBuilder._get_retention_period(amount, duration))
+
+    @staticmethod
+    def _get_retention_period(amount, duration):
+        retain_for = Object()
+        retain_for._classname = 'WormPeriod'  # pylint: disable=protected-access
+        retain_for.amount = amount
+        retain_for.type = duration
+        return retain_for
+
+    def grace_period(self, amount=30, duration=Duration.Minutes):
+        self.settings.gracePeriod = self._get_retention_period(amount, duration)
+        return self
+
+    def build(self):
+        if self.settings.gracePeriod is None:
+            self.grace_period()
+        return self.settings
+
+
+class ExtendedAttribute(Object):
+
+    def __init__(self, name, supported):
+        super().__init__()
+        self._classname = 'ExtendedAttributesInfo'  # pylint: disable=protected-access
+        self.name = name
+        self.supported = supported
+
+
+class ExtendedAttributesBuilder:
+
+    def __init__(self, enable, xattrs):
+        self.xattrs = Object()
+        self.xattrs._classname = 'ExtendedAttributes'  # pylint: disable=protected-access
+        self.xattrs.enable = enable
+        self.xattrs.attributes = xattrs
+
+    @staticmethod
+    def default():
+        return ExtendedAttributesBuilder(True, [ExtendedAttribute(ExtendedAttributes.MacOS, True)])
+
+    @staticmethod
+    def disabled():
+        return ExtendedAttributesBuilder(False, [ExtendedAttribute(ExtendedAttributes.MacOS, True)])
+
+    def add(self, xattr):
+        """
+        :param cterasdk.core.enum.ExtendedAttributes xattr: Extended attribute
+        """
+        self.xattrs.append(xattr)
+
+    def build(self):
+        return self.xattrs
+
+
+class RoleSettings(Object):  # pylint: disable=too-many-instance-attributes
+    """
+    Role Settings
+
+    :ivar str name: Role name
+    :ivar bool sudo: Super user
+    :ivar bool enable_remote_wipe: Allow Remote Wipe for Devices
+    :ivar bool enable_sso: Super user
+    :ivar bool enable_seeding_export: Allow Seeding Export
+    :ivar bool enable_seeding_import: Allow Seeding Import
+    :ivar bool access_end_user_folders: Access End User Folders
+    :ivar bool update_settings: Modify Virtual Portal Settings
+    :ivar bool update_roles: Modify Roles
+    :ivar bool update_account_emails: Modify User Email
+    :ivar bool update_account_password: Modify User Password
+    :ivar bool manage_cloud_drives: Manage Cloud Folders
+    :ivar bool manage_plans: Manage Plans
+    :ivar bool manage_logs: Manage Log Settings
+    :ivar bool allow_folders_files_permanent_delete: Allow Folders Files Permanent Delete
+    :ivar bool can_manage_legal_holds: Manage Legal Holds
+    :ivar bool can_manage_compliance_settings: Manage Compliance Settings
+    """
+    # pylint: disable=too-many-arguments, too-many-locals
+    def __init__(self, name, sudo, enable_remote_wipe, enable_sso, enable_seeding_export, enable_seeding_import, access_end_user_folders,
+                 update_settings, update_roles, update_account_emails, update_account_password, manage_cloud_drives, manage_plans,
+                 manage_users, manage_logs, allow_folders_files_permanent_delete, can_manage_legal_holds, can_manage_compliance_settings):
+        super().__init__()
+        self.name = name
+        self.sudo = sudo
+        self.enable_remote_wipe = enable_remote_wipe
+        self.enable_sso = enable_sso
+        self.enable_seeding_export = enable_seeding_export
+        self.enable_seeding_import = enable_seeding_import
+        self.access_end_user_folders = access_end_user_folders
+        self.update_settings = update_settings
+        self.update_roles = update_roles
+        self.update_account_emails = update_account_emails
+        self.update_account_password = update_account_password
+        self.manage_cloud_drives = manage_cloud_drives
+        self.manage_plans = manage_plans
+        self.manage_users = manage_users
+        self.manage_logs = manage_logs
+        self.allow_folders_files_permanent_delete = allow_folders_files_permanent_delete
+        self.can_manage_legal_holds = can_manage_legal_holds
+        self.can_manage_compliance_settings = can_manage_compliance_settings
+
+    def to_server_object(self):
+        param = Object()
+        param._classname = 'PortalRoleSettings'  # pylint: disable=protected-access
+        param.name = self.name
+        param.superUser = self.sudo
+        param.allowRemoteWipe = self.enable_remote_wipe
+        param.allowSSO = self.enable_sso
+        param.allowSeedingExport = self.enable_seeding_export
+        param.allowSeedingImport = self.enable_seeding_import
+        param.canAccessEndUserFolders = self.access_end_user_folders
+        param.canChangePortalSettings = self.update_settings
+        param.canChangeRoles = self.update_roles
+        param.canChangeUserEmail = self.update_account_emails
+        param.canChangeUserPassword = self.update_account_password
+        param.canManageAllFolders = self.manage_cloud_drives
+        param.canManagePlans = self.manage_plans
+        param.canManageUsers = self.manage_users
+        param.canManageLogSettings = self.manage_logs
+        param.allowFoldersFilesPermanentDelete = self.allow_folders_files_permanent_delete
+        param.canManageLegalHolds = self.can_manage_legal_holds
+        param.canManageComplianceSetting = self.can_manage_compliance_settings
+        return param
+
+    @staticmethod
+    def from_server_object(server_object):
+        params = {
+            'name': server_object.name,
+            'sudo': server_object.superUser,
+            'enable_remote_wipe': server_object.allowRemoteWipe,
+            'enable_sso': server_object.allowSSO,
+            'enable_seeding_export': server_object.allowSeedingExport,
+            'enable_seeding_import': server_object.allowSeedingImport,
+            'access_end_user_folders': server_object.canAccessEndUserFolders,
+            'update_settings': server_object.canChangePortalSettings,
+            'update_roles': server_object.canChangeRoles,
+            'update_account_emails': server_object.canChangeUserEmail,
+            'update_account_password': server_object.canChangeUserPassword,
+            'manage_cloud_drives': server_object.canManageAllFolders,
+            'manage_plans': server_object.canManagePlans,
+            'manage_users': server_object.canManageUsers,
+            'manage_logs': server_object.canManageLogSettings,
+            'allow_folders_files_permanent_delete': server_object.allowFoldersFilesPermanentDelete,
+            'can_manage_legal_holds': server_object.canManageLegalHolds,
+            'can_manage_compliance_settings': server_object.canManageComplianceSetting
+        }
+        return RoleSettings(**params)
