@@ -1,13 +1,16 @@
 import logging
 
 from . import enum
-from .files import path
+from ..cio.edge import EdgePath
 from ..common import Object
-from ..exception import CTERAException, InputError
+from ..exceptions import CTERAException, InputError
 from .base_command import BaseCommand
 from .types import NFSv3AccessControlEntry, RemoveNFSv3AccessControlEntry, ShareAccessControlEntry, RemoveShareAccessControlEntry
 
 
+logger = logging.getLogger('cterasdk.edge')
+
+
 class Shares(BaseCommand):
 
     def get(self, name=None):
@@ -15,7 +18,7 @@ class Shares(BaseCommand):
         Get Share. If a share name was not passed as an argument, a list of all shares will be retrieved
         :param str,optional name: Name of the share
         """
-        return self._gateway.get('/config/fileservices/share' + ('' if name is None else ('/' + name)))
+        return self._edge.api.get('/config/fileservices/share' + ('' if name is None else ('/' + name)))
 
     def add(self,
             name,
@@ -57,7 +60,7 @@ class Shares(BaseCommand):
         param = Object()
         param.name = name
 
-        parts = path.CTERAPath(directory, '/').parts()
+        parts = EdgePath('/', directory).parts
         volume = parts[0]
         self._validate_root_directory(volume)
         param.volume = volume
@@ -82,11 +85,11 @@ class Shares(BaseCommand):
             param._uuid = uuid  # pylint: disable=protected-access
 
         try:
-            self._gateway.add('/config/fileservices/share', param)
-            logging.getLogger().info("Share created. %s", {'name': name})
-        except Exception as error:
-            logging.getLogger().error("Share creation failed.")
-            raise CTERAException('Share creation failed', error)
+            self._edge.api.add('/config/fileservices/share', param)
+            logger.info("Share created. %s", {'name': param.name})
+        except CTERAException as error:
+            logger.error("Share creation failed: %s", param.name)
+            raise CTERAException(f'Share creation failed: {param.name}') from error
 
     def set_share_winacls(self, name):
         """
@@ -94,8 +97,8 @@ class Shares(BaseCommand):
 
         :param str name: The share name
         """
-        logging.getLogger().error("Updating Windows file sharing access mode. %s", {'share': name, 'access': enum.Acl.WindowsNT})
-        self._gateway.put('/config/fileservices/share/' + name + '/access', enum.Acl.WindowsNT)
+        logger.error("Updating Windows file sharing access mode. %s", {'share': name, 'access': enum.Acl.WindowsNT})
+        self._edge.api.put('/config/fileservices/share/' + name + '/access', enum.Acl.WindowsNT)
 
     def get_access_type(self, name):
         """
@@ -103,7 +106,7 @@ class Shares(BaseCommand):
 
         :param str name: The share name
         """
-        return self._gateway.get('/config/fileservices/share/' + name + '/access')
+        return self._edge.api.get('/config/fileservices/share/' + name + '/access')
 
     def set_access_type(self, name, access):
         """
@@ -112,8 +115,8 @@ class Shares(BaseCommand):
         :param str name: The share name
         :param cterasdk.edge.enum.Acl access: The Windows File Sharing authentication mode
         """
-        logging.getLogger().info("Updating Windows file sharing access mode. %s", {'share': name, 'access': access})
-        self._gateway.put('/config/fileservices/share/' + name + '/access', access)
+        logger.info("Updating Windows file sharing access mode. %s", {'share': name, 'access': access})
+        self._edge.api.put('/config/fileservices/share/' + name + '/access', access)
 
     def block_files(self, name, extensions):
         """
@@ -123,11 +126,10 @@ class Shares(BaseCommand):
         :param list[str] extensions: List of file extensions to block
         """
         share = self.get(name)
-        if share.access != enum.Acl.WindowsNT:
-            raise CTERAException('Cannot block file types on non Windows-ACL enabled shares', None, share=share.name, access=share.access)
-        logging.getLogger().error("Updating the list of blocked file extensions. %s",
-                                  {'share': name, 'extensions': extensions, 'access': enum.Acl.WindowsNT})
-        self._gateway.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', extensions)
+        Shares._validate_share_access(share)
+        logger.error("Updating the list of blocked file extensions. %s",
+                     {'share': name, 'extensions': extensions, 'access': enum.Acl.WindowsNT})
+        self._edge.api.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', extensions)
 
     def set_acl(self, name, acl):
         """
@@ -141,7 +143,7 @@ class Shares(BaseCommand):
         Shares._validate_acl(acl)
 
         param = [acl_entry.to_server_object() for acl_entry in acl]
-        self._gateway.put('/config/fileservices/share/' + name + '/acl', param)
+        self._edge.api.put('/config/fileservices/share/' + name + '/acl', param)
 
     def add_acl(self, name, acl):
         """
@@ -166,7 +168,7 @@ class Shares(BaseCommand):
                 new_acl_dict[entry_key] = entry
 
         acls_array = [v for k, v in new_acl_dict.items()]
-        self._gateway.put('/config/fileservices/share/' + name + '/acl', acls_array)
+        self._edge.api.put('/config/fileservices/share/' + name + '/acl', acls_array)
 
     def remove_acl(self, name, acl):
         """
@@ -190,7 +192,7 @@ class Shares(BaseCommand):
             if not remove_acl_dict.get(ace.principal_type + '#' + ace.name, False):
                 new_acl.append(entry)
 
-        self._gateway.put('/config/fileservices/share/' + name + '/acl', new_acl)
+        self._edge.api.put('/config/fileservices/share/' + name + '/acl', new_acl)
 
     def get_acl(self, name):
         """
@@ -198,7 +200,7 @@ class Shares(BaseCommand):
 
         :param str name: The share name
         """
-        return self._gateway.get('/config/fileservices/share/' + name + '/acl')
+        return self._edge.api.get('/config/fileservices/share/' + name + '/acl')
 
     def modify(
             self,
@@ -237,7 +239,7 @@ class Shares(BaseCommand):
         """
         share = self.get(name=name)
         if directory is not None:
-            parts = path.CTERAPath(directory, '/').parts()
+            parts = EdgePath('/', directory).parts
             volume = parts[0]
             self._validate_root_directory(volume)
             share.volume = volume
@@ -270,12 +272,12 @@ class Shares(BaseCommand):
             share.trustedNFSClients = [client.to_server_object() for client in trusted_nfs_clients]
 
         try:
-            self._gateway.put('/config/fileservices/share/' + name, share)
-            logging.getLogger().info("Share modified. %s", {'name': name})
+            self._edge.api.put('/config/fileservices/share/' + name, share)
+            logger.info("Share modified. %s", {'name': name})
         except Exception as error:
-            msg = f'Failed to modify the share {name}'
-            logging.getLogger().error(msg)
-            raise CTERAException(msg, error)
+            message = f'Could not modify share: {name}'
+            logger.error(message)
+            raise CTERAException(message) from error
 
     def delete(self, name):
         """
@@ -283,12 +285,13 @@ class Shares(BaseCommand):
 
         :param str name: The share name
         """
+        ref = f'/config/fileservices/share/{name}'
         try:
-            self._gateway.delete('/config/fileservices/share/' + name)
-            logging.getLogger().info("Share deleted. %s", {'name': name})
+            self._edge.api.delete(ref)
+            logger.info("Share deleted: %s", ref)
         except Exception as error:
-            logging.getLogger().error("Share deletion failed.")
-            raise CTERAException('Share deletion failed', error)
+            logger.error("Share deletion failed: %s", ref)
+            raise CTERAException(f'Share deletion failed: {ref}') from error
 
     def get_trusted_nfs_clients(self, name):
         """
@@ -296,7 +299,7 @@ class Shares(BaseCommand):
 
         :param str name: The share name
         """
-        return self._gateway.get('/config/fileservices/share/' + name + '/trustedNFSClients')
+        return self._edge.api.get('/config/fileservices/share/' + name + '/trustedNFSClients')
 
     def set_trusted_nfs_clients(self, name, trusted_nfs_clients):
         """
@@ -310,7 +313,7 @@ class Shares(BaseCommand):
         Shares._validate_trusted_nfs_clients(trusted_nfs_clients)
 
         param = [client.to_server_object() for client in (trusted_nfs_clients or [])]
-        self._gateway.put('/config/fileservices/share/' + name + '/trustedNFSClients', param)
+        self._edge.api.put('/config/fileservices/share/' + name + '/trustedNFSClients', param)
 
     def add_trusted_nfs_clients(self, name, trusted_nfs_clients):
         """
@@ -333,7 +336,7 @@ class Shares(BaseCommand):
 
         param = list(new_trusted_nfs_clients_dict.values()) + list(filter(entry_not_in_new, self.get_trusted_nfs_clients(name)))
 
-        self._gateway.put('/config/fileservices/share/' + name + '/trustedNFSClients', param)
+        self._edge.api.put('/config/fileservices/share/' + name + '/trustedNFSClients', param)
 
     def remove_trusted_nfs_clients(self, name, trusted_nfs_clients):
         """
@@ -355,7 +358,7 @@ class Shares(BaseCommand):
             return entry_key not in remove_trusted_nfs_clients_dict
 
         param = list(filter(entry_not_removed, self.get_trusted_nfs_clients(name)))
-        self._gateway.put('/config/fileservices/share/' + name + '/trustedNFSClients', param)
+        self._edge.api.put('/config/fileservices/share/' + name + '/trustedNFSClients', param)
 
     def get_screened_file_types(self, name):
         """
@@ -363,7 +366,7 @@ class Shares(BaseCommand):
 
         :param str name: The share name
         """
-        return self._gateway.get('/config/fileservices/share/' + name + '/screenedFileTypes')
+        return self._edge.api.get('/config/fileservices/share/' + name + '/screenedFileTypes')
 
     def set_screened_file_types(self, name, extensions):
         """
@@ -373,13 +376,12 @@ class Shares(BaseCommand):
         :param list[str] extensions: List of file extensions to block
         """
         share = self.get(name)
-        if share.access != enum.Acl.WindowsNT:
-            raise CTERAException('Cannot block file types on non Windows-ACL enabled shares', None, share=share.name, access=share.access)
-        logging.getLogger().info(
+        Shares._validate_share_access(share)
+        logger.info(
             "Updating the list of blocked file extensions. %s",
             {'share': name, 'extensions': extensions, 'access': enum.Acl.WindowsNT}
         )
-        self._gateway.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', extensions)
+        self._edge.api.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', extensions)
 
     def add_screened_file_types(self, name, extensions):
         """
@@ -389,16 +391,15 @@ class Shares(BaseCommand):
         :param list[str] extensions: List of file extensions to add
         """
         share = self.get(name)
-        if share.access != enum.Acl.WindowsNT:
-            raise CTERAException('Cannot block file types on non Windows-ACL enabled shares', None, share=share.name, access=share.access)
+        Shares._validate_share_access(share)
 
         new_list = list(set(share.screenedFileTypes + extensions))
 
-        logging.getLogger().info(
+        logger.info(
             "Updating the list of blocked file extensions. %s",
             {'share': name, 'extensions': new_list, 'access': enum.Acl.WindowsNT}
         )
-        self._gateway.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', new_list)
+        self._edge.api.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', new_list)
 
     def remove_screened_file_types(self, name, extensions):
         """
@@ -408,32 +409,35 @@ class Shares(BaseCommand):
         :param list[str] extensions: List of file extensions to remove
         """
         share = self.get(name)
-        if share.access != enum.Acl.WindowsNT:
-            raise CTERAException('Cannot block file types on non Windows-ACL enabled shares', None, share=share.name, access=share.access)
+        Shares._validate_share_access(share)
 
         new_list = list(set(share.screenedFileTypes) - set(extensions))
 
-        logging.getLogger().info(
+        logger.info(
             "Updating the list of blocked file extensions. %s",
             {'share': name, 'extensions': new_list, 'access': enum.Acl.WindowsNT}
         )
-        self._gateway.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', new_list)
+        self._edge.api.put('/config/fileservices/share/' + share.name + '/screenedFileTypes', new_list)
 
     def _validate_root_directory(self, name):
         param = Object()
         param.path = '/'
-
-        response = self._gateway.execute('/status/fileManager', 'listPhysicalFolders', param)
+        response = self._edge.api.execute('/status/fileManager', 'listPhysicalFolders', param)
         for root in response:
             if root.fullpath == f'/{name}':
-                logging.getLogger().debug("Found root directory. %s", {'name': root.name, 'type': root.type, 'fullpath': root.fullpath})
+                logger.debug("Found root directory. %s", {'name': root.name, 'type': root.type, 'fullpath': root.fullpath})
                 return name
 
-        logging.getLogger().error("Could not find root directory. %s", {'name': name})
+        logger.error("Could not find root directory. %s", {'name': name})
 
         options = [root.fullpath[1:] for root in response]
         raise InputError('Invalid root directory.', name, options)
 
+    @staticmethod
+    def _validate_share_access(share):
+        if share.access != enum.Acl.WindowsNT:
+            raise CTERAException('Cannot block file types on non Windows-ACL enabled shares.')
+
     @staticmethod
     def _validate_acl(acl):
         if not isinstance(acl, list):
